=============
SQL Interface
=============

This page gives an overview of all public SQL functions
and operations supported by Polars.


.. raw:: html

    <style>
      div.sd-card-body.docutils li.toctree-l1 > :first-child {display: none;}
    </style>


.. grid::

    .. grid-item-card::

        **Python API**
        ^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 3

           python_api

    .. grid-item-card::

        **SQL Clauses**
        ^^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           clauses

    .. grid-item-card::

        **SQL Functions**
        ^^^^^^^^^^^^^^^^^

        :doc:`Overview <functions/index>`

        .. toctree::
           :maxdepth: 2

           functions/index

.. grid::

    .. grid-item-card::

        **Set Operations**
        ^^^^^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           set_operations

    .. grid-item-card::

        **Table Operations**
        ^^^^^^^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           table_operations

    .. grid-item-card::
